@@ -9,19 +9,64 @@ var versionInfo = require('./lib/versions/version-info');
 var path = require('path');
 var e2e = require('./test/e2e/tools');
 
+var semver = require('semver');
+var exec = require('shelljs').exec;
+var pkg = require(__dirname + '/package.json');
+
+// Node.js version checks
+if (!semver.satisfies(process.version, pkg.engines.node)) {
+  reportOrFail('Invalid node version (' + process.version + '). ' +
+               'Please use a version that satisfies ' + pkg.engines.node);
+}
+
+// Yarn version checks
+var expectedYarnVersion = pkg.engines.yarn;
+var currentYarnVersion = exec('yarn --version', {silent: true}).stdout.trim();
+if (!semver.satisfies(currentYarnVersion, expectedYarnVersion)) {
+  reportOrFail('Invalid yarn version (' + currentYarnVersion + '). ' +
+               'Please use a version that satisfies ' + expectedYarnVersion);
+}
+
+// Grunt CLI version checks
+var expectedGruntVersion = pkg.engines.grunt;
+var currentGruntVersions = exec('grunt --version', {silent: true}).stdout;
+var match = /^grunt-cli v(.+)$/m.exec(currentGruntVersions);
+if (!match) {
+  reportOrFail('Unable to compute the current grunt-cli version. We found:\n' +
+               currentGruntVersions);
+} else {
+  if (!semver.satisfies(match[1], expectedGruntVersion)) {
+  reportOrFail('Invalid grunt-cli version (' + match[1] + '). ' +
+               'Please use a version that satisfies ' + expectedGruntVersion);
+  }
+}
+
+// Ensure Node.js dependencies have been installed
+if (!process.env.TRAVIS && !process.env.JENKINS_HOME) {
+  var yarnOutput = exec('yarn install');
+  if (yarnOutput.code !== 0) {
+    throw new Error('Yarn install failed: ' + yarnOutput.stderr);
+  }
+}
+
+
 module.exports = function(grunt) {
-  //grunt plugins
+
+  // this loads all the node_modules that start with `grunt-` as plugins
   require('load-grunt-tasks')(grunt);
 
+  // load additional grunt tasks
   grunt.loadTasks('lib/grunt');
   grunt.loadNpmTasks('angular-benchpress');
 
+  // compute version related info for this build
   var NG_VERSION = versionInfo.currentVersion;
   NG_VERSION.cdn = versionInfo.cdnVersion;
   var dist = 'angular-' + NG_VERSION.full;
 
   if (versionInfo.cdnVersion == null) {
-    throw new Error('Unable to read CDN version, are you offline or has the CDN not been properly pushed?');
+    throw new Error('Unable to read CDN version, are you offline or has the CDN not been properly pushed?\n' +
+                    'Perhaps you want to set the NG1_BUILD_NO_REMOTE_VERSION_REQUESTS environment variable?');
   }
 
   //config
@@ -284,17 +329,16 @@ module.exports = function(grunt) {
     },
 
     shell: {
-      'npm-install': {
-        command: 'node scripts/npm/check-node-modules.js'
+      'install-node-dependencies': {
+        command: 'yarn'
       },
-
       'promises-aplus-tests': {
         options: {
           stdout: false,
           stderr: true,
           failOnError: true
         },
-        command: path.normalize('./node_modules/.bin/promises-aplus-tests tmp/promises-aplus-adapter++.js')
+        command: path.normalize('./node_modules/.bin/promises-aplus-tests tmp/promises-aplus-adapter++.js --timeout 2000')
       }
     },
 
@@ -314,13 +358,6 @@ module.exports = function(grunt) {
     }
   });
 
-  // global beforeEach task
-  if (!process.env.TRAVIS) {
-    grunt.task.run('shell:npm-install');
-  }
-
-
-
   //alias tasks
   grunt.registerTask('test', 'Run unit, docs and e2e tests with Karma', ['eslint', 'package', 'test:unit', 'test:promises-aplus', 'tests:docs', 'test:protractor']);
   grunt.registerTask('test:jqlite', 'Run the unit tests with Karma' , ['tests:jqlite']);
@@ -338,7 +375,18 @@ module.exports = function(grunt) {
 
   grunt.registerTask('minify', ['bower', 'clean', 'build', 'minall']);
   grunt.registerTask('webserver', ['connect:devserver']);
-  grunt.registerTask('package', ['bower', 'validate-angular-files', 'clean', 'buildall', 'minall', 'collect-errors', 'docs', 'copy', 'write', 'compress']);
+  grunt.registerTask('package', ['bower', 'validate-angular-files', 'clean', 'buildall', 'minall', 'collect-errors', 'write', 'docs', 'copy', 'compress']);
   grunt.registerTask('ci-checks', ['ddescribe-iit', 'merge-conflict', 'eslint']);
   grunt.registerTask('default', ['package']);
 };
+
+
+function reportOrFail(message) {
+  if (process.env.TRAVIS || process.env.JENKINS_HOME) {
+    throw new Error(message);
+  } else {
+    console.log('===============================================================================');
+    console.log(message);
+    console.log('===============================================================================');
+  }
+}
