@@ -1,14 +1,12 @@
 'use strict';
 
-angular.module('DocsController', [])
+angular.module('DocsController', ['currentVersionData'])
 
 .controller('DocsController', [
           '$scope', '$rootScope', '$location', '$window', '$cookies',
-              'NG_PAGES', 'NG_NAVIGATION', 'NG_VERSION',
+              'NG_PAGES', 'NG_NAVIGATION', 'CURRENT_NG_VERSION',
   function($scope, $rootScope, $location, $window, $cookies,
-              NG_PAGES, NG_NAVIGATION, NG_VERSION) {
-
-  $scope.docsVersion = NG_VERSION.isSnapshot ? 'snapshot' : NG_VERSION.version;
+              NG_PAGES, NG_NAVIGATION, CURRENT_NG_VERSION) {
 
   $scope.navClass = function(navItem) {
     return {
@@ -23,6 +21,11 @@ angular.module('DocsController', [])
   $scope.$on('$includeContentLoaded', function() {
     var pagePath = $scope.currentPage ? $scope.currentPage.path : $location.path();
     $window._gaq.push(['_trackPageview', pagePath]);
+    $scope.loading = false;
+  });
+
+  $scope.$on('$includeContentError', function() {
+    $scope.loading = false;
   });
 
   $scope.$watch(function docsPathWatch() {return $location.path(); }, function docsPathWatchAction(path) {
@@ -31,6 +34,8 @@ angular.module('DocsController', [])
 
     var currentPage = $scope.currentPage = NG_PAGES[path];
 
+    $scope.loading = true;
+
     if (currentPage) {
       $scope.partialPath = 'partials/' + path + '.html';
       $scope.currentArea = NG_NAVIGATION[currentPage.area];
@@ -53,12 +58,12 @@ angular.module('DocsController', [])
    Initialize
    ***********************************/
 
-  $scope.versionNumber = angular.version.full;
-  $scope.version = angular.version.full + '  ' + angular.version.codeName;
+  $scope.versionNumber = CURRENT_NG_VERSION.full;
+  $scope.version = CURRENT_NG_VERSION.full + ' ' + CURRENT_NG_VERSION.codeName;
   $scope.loading = 0;
 
 
-  var INDEX_PATH = /^(\/|\/index[^\.]*.html)$/;
+  var INDEX_PATH = /^(\/|\/index[^.]*.html)$/;
   if (!$location.path() || INDEX_PATH.test($location.path())) {
     $location.path('/api').replace();
   }
