@@ -1,8 +1,9 @@
+'use strict';
+
 angular.module('examples', [])
 
-.directive('runnableExample', ['$templateCache', '$document', function($templateCache, $document) {
+.directive('runnableExample', [function() {
   var exampleClassNameSelector = '.runnable-example-file';
-  var doc = $document[0];
   var tpl =
     '<nav class="runnable-example-tabs" ng-if="tabs">' +
     '  <a ng-class="{active:$index==activeTabIndex}"' +
@@ -29,12 +30,12 @@ angular.module('examples', [])
       return function(scope, element) {
         var node = element[0];
         var examples = node.querySelectorAll(exampleClassNameSelector);
-        var tabs = [], now = Date.now();
+        var tabs = [];
         angular.forEach(examples, function(child, index) {
           tabs.push(child.getAttribute('name'));
         });
 
-        if(tabs.length > 0) {
+        if (tabs.length > 0) {
           scope.tabs = tabs;
           scope.$on('tabChange', function(e, index, title) {
             angular.forEach(examples, function(child) {
@@ -101,7 +102,7 @@ angular.module('examples', [])
     },
     controllerAs: 'plnkr',
     template: '<button ng-click="plnkr.open($event)" class="btn pull-right"> <i class="glyphicon glyphicon-edit">&nbsp;</i> Edit in Plunker</button> ',
-    controller: [function() {
+    controller: [function PlnkrOpenerCtrl() {
       var ctrl = this;
 
       ctrl.example = {
@@ -137,8 +138,8 @@ angular.module('examples', [])
         var newWindow = clickEvent.ctrlKey || clickEvent.metaKey;
 
         var postData = {
-          'tags[0]': "angularjs",
-          'tags[1]': "example",
+          'tags[0]': 'angularjs',
+          'tags[1]': 'example',
           'private': true
         };
 
@@ -167,7 +168,7 @@ angular.module('examples', [])
 }])
 
 .factory('getExampleData', ['$http', '$q', function($http, $q) {
-  return function(exampleFolder){
+  return function(exampleFolder) {
     // Load the manifest for the example
     return $http.get(exampleFolder + '/manifest.json')
       .then(function(response) {
@@ -182,8 +183,8 @@ angular.module('examples', [])
 
               // The manifests provide the production index file but Plunkr wants
               // a straight index.html
-              if (filename === "index-production.html") {
-                filename = "index.html";
+              if (filename === 'index-production.html') {
+                filename = 'index.html';
               }
 
               return {
@@ -199,4 +200,4 @@ angular.module('examples', [])
         });
       });
   };
-}]);
\ No newline at end of file
+}]);
