@@ -72,7 +72,7 @@ angular.module('search', [])
 
 .controller('Error404SearchCtrl', ['$scope', '$location', 'docsSearch',
         function($scope, $location, docsSearch) {
-  docsSearch($location.path().split(/[\/\.:]/).pop()).then(function(results) {
+  docsSearch($location.path().split(/[/.:]/).pop()).then(function(results) {
     $scope.results = {};
     angular.forEach(results, function(result) {
       var area = $scope.results[result.area] || [];
@@ -202,13 +202,13 @@ angular.module('search', [])
   };
 })
 
-.directive('docsSearchInput', ['$document',function($document) {
+.directive('docsSearchInput', ['$document', function($document) {
   return function(scope, element, attrs) {
     var ESCAPE_KEY_KEYCODE = 27,
         FORWARD_SLASH_KEYCODE = 191;
     angular.element($document[0].body).on('keydown', function(event) {
       var input = element[0];
-      if (event.keyCode === FORWARD_SLASH_KEYCODE && window.document.activeElement !== input) {
+      if (event.keyCode === FORWARD_SLASH_KEYCODE && $document[0].activeElement !== input) {
         event.stopPropagation();
         event.preventDefault();
         input.focus();
