@@ -1,7 +1,4 @@
-"use strict";
-
-var _ = require('lodash');
-var path = require('canonical-path');
+'use strict';
 
 /**
  * @dgProcessor errorDocsProcessor
@@ -18,7 +15,7 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
       docs.forEach(function(doc) {
         var parts, namespaceDoc;
 
-        if ( doc.docType === 'error' ) {
+        if (doc.docType === 'error') {
 
           // Parse out the error info from the id
           parts = doc.name.split(':');
@@ -27,7 +24,7 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
 
           // Get or create the relevant errorNamespace doc
           namespaceDoc = errorNamespaceMap.get(doc.namespace);
-          if ( !namespaceDoc ) {
+          if (!namespaceDoc) {
             namespaceDoc = {
               area: 'error',
               name: doc.namespace,
@@ -49,4 +46,4 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
       });
     }
   };
-};
\ No newline at end of file
+};
