@@ -1,13 +1,9 @@
-"use strict";
-
-var fs = require('fs');
-var _ = require('lodash');
-var stripJsonComments = require('strip-json-comments');
+'use strict';
 
 var gulp = require('gulp');
 var log = require('gulp-util').log;
 var concat = require('gulp-concat');
-var jshint = require('gulp-jshint');
+var eslint = require('gulp-eslint');
 var bower = require('bower');
 var Dgeni = require('dgeni');
 var merge = require('event-stream').merge;
@@ -29,28 +25,41 @@ var ignoredFiles = '!src/angular.bind.js';
 var assets = 'app/assets/**/*';
 
 
-var getJshintConfig = function(filepath) {
-    return JSON.parse(stripJsonComments(fs.readFileSync(filepath, {encoding: 'utf-8'})));
-};
+var getMergedEslintConfig = function(filepath) {
+  return {
+    configFile: filepath,
+    baseConfig: '../.eslintrc.json',
+    rules: {
+      // Examples don't run in strict mode; accept that for now.
+      strict: 'off',
+      // Generated examples may miss the final EOL; ignore that.
+      'eol-last': 'off',
+      // Generated files use the system's default linebreak style (e.g. CRLF on Windows)
+      'linebreak-style': 'off',
+      // While alerts would be bad to have in the library or test code,
+      // they're perfectly fine in examples.
+      'no-alert': 'off',
 
-var getMergedJshintConfig = function(filepath) {
-  // "extends" doesn't work in configuration passed by an object, we need to do the extending ourselves.
-  var config = getJshintConfig(filepath);
-  var baseConfig = getJshintConfig('../.jshintrc-base');
-  _.merge(config, baseConfig);
-  delete config.extends;
+      // The following rules have to be disabled or tweaked because dgeni template wrappers
+      // don't follow them and we have no way to validate only the parts taken
+      // from ngdoc.
 
-  // Examples don't run in strict mode; accept that for now.
-  config.strict = false;
+      // some dgeni-packages templates generate whitespace-only lines
+      'no-trailing-spaces': ['error', { 'skipBlankLines': true }],
 
-  return config;
+      // dgeni templates use double quotes as string delimiters
+      quotes: 'off'
+    },
+    ignore: false,
+    useEslintrc: false
+  };
 };
 
 var copyComponent = function(component, pattern, sourceFolder, packageFile) {
   pattern = pattern || '/**/*';
   sourceFolder = sourceFolder || bowerFolder;
   packageFile = packageFile || 'bower.json';
-  var version = require(path.resolve(sourceFolder,component,packageFile)).version;
+  var version = require(path.resolve(sourceFolder, component, packageFile)).version;
   return gulp
     .src(sourceFolder + '/' + component + pattern)
     .pipe(gulp.dest(outputFolder + '/components/' + component + '-' + version));
@@ -58,7 +67,7 @@ var copyComponent = function(component, pattern, sourceFolder, packageFile) {
 
 gulp.task('bower', function() {
   var bowerTask = bower.commands.install();
-  bowerTask.on('log', function (result) {
+  bowerTask.on('log', function(result) {
     log('bower:', result.id, result.data.endpoint.name);
   });
   bowerTask.on('error', function(error) {
@@ -101,7 +110,7 @@ gulp.task('assets', ['bower'], function() {
       })),
     copyComponent('bootstrap', '/dist/**/*'),
     copyComponent('open-sans-fontface'),
-    copyComponent('lunr.js','/*.js'),
+    copyComponent('lunr.js', '/*.js'),
     copyComponent('google-code-prettify'),
     copyComponent('jquery', '/dist/*.js'),
     copyComponent('marked', '/**/*.js', '../node_modules', 'package.json')
@@ -116,35 +125,51 @@ gulp.task('doc-gen', ['bower'], function() {
   });
 });
 
-// JSHint the example and protractor test files
-gulp.task('jshint', ['doc-gen'], function() {
-  var examplesConfig = getMergedJshintConfig('../docs/app/test/.jshintrc');
-  // Some tests use `alert` which is not assumed to be available even with `"browser": true`.
-  examplesConfig.globals.alert = false;
 
-  var protractorConfig = getMergedJshintConfig('../docs/app/e2e/.jshintrc');
+// Lint the example and protractor test files
+gulp.task('eslint', ['doc-gen'], function() {
+  var examplesConfig = getMergedEslintConfig('../docs/app/test/.eslintrc.json');
+  // While in source we don't want to assume the browser environment so that we're
+  // compatible with non-browser window implementations like jsdom, it's not necessary
+  // in examples and may look weird to casual readers.
+  examplesConfig.envs = ['browser'];
+
+  var protractorConfig = getMergedEslintConfig('../docs/app/e2e/.eslintrc.json');
+  protractorConfig.rules['no-unused-vars'] = ['error', {
+    vars: 'local',
+    args: 'none',
+    // This variable is declared in code generated by dgeni-packages
+    // and not always used.
+    varsIgnorePattern: '^rootEl$'
+  }];
 
   return merge(
     gulp.src([
       outputFolder + '/examples/**/*.js',
-      '!' + outputFolder + '/examples/**/protractor.js',
+      '!' + outputFolder + '/examples/**/protractor.js'
     ])
-      .pipe(jshint(examplesConfig))
-      .pipe(jshint.reporter('jshint-stylish'))
-      .pipe(jshint.reporter('fail')),
+      // eslint() attaches the lint output to the "eslint" property
+      // of the file object so it can be used by other modules.
+      .pipe(eslint(examplesConfig))
+      // eslint.format() outputs the lint results to the console.
+      // Alternatively use eslint.formatEach() (see Docs).
+      .pipe(eslint.format())
+      // To have the process exit with an error code (1) on
+      // lint error, return the stream and pipe to failAfterError last.
+      .pipe(eslint.failAfterError()),
     gulp.src([
       outputFolder + '/ptore2e/**/*.js',
-      outputFolder + '/examples/**/protractor.js',
+      outputFolder + '/examples/**/protractor.js'
     ])
-      .pipe(jshint(protractorConfig))
-      .pipe(jshint.reporter('jshint-stylish'))
-      .pipe(jshint.reporter('fail'))
+      .pipe(eslint(protractorConfig))
+      .pipe(eslint.format())
+      .pipe(eslint.failAfterError())
   );
 });
 
 
 // The default task that will be run if no task is supplied
-gulp.task('default', ['assets', 'doc-gen', 'build-app', 'jshint']);
+gulp.task('default', ['assets', 'doc-gen', 'build-app', 'eslint']);
 
 gulp.task('watch', function() {
   gulp.watch([src, ignoredFiles, assets], ['assets', 'build-app']);
