@@ -6,8 +6,6 @@ config.specs = [
   'app/e2e/**/*.scenario.js'
 ];
 
-config.capabilities = {
-  browserName: 'chrome',
-};
+config.capabilities.browserName = 'chrome';
 
 exports.config = config;
