@@ -3,21 +3,15 @@
 
 var Q  = require('q'),
     qfs  = require('q-io/fs'),
-    converter = require('./converter.js'),
-    util = require('./util.js'),
     closureI18nExtractor = require('./closureI18nExtractor.js'),
-    localeInfo = {},
-    currencySymbols,
-    goog = { provide: function() {},
-             require: function() {},
-             i18n: {currency: {}, pluralRules: {}} };
+    localeInfo = {};
 
 
 var NG_LOCALE_DIR = '../src/ngLocale/';
 
 
 function readSymbols() {
-  console.log("Processing currency and number symbols ...");
+  console.log('Processing currency and number symbols ...');
   var numericStagePromise = qfs.read(__dirname + '/../closure/currencySymbols.js', 'b')
     .then(function(content) {
       var currencySymbols = closureI18nExtractor.extractCurrencySymbols(content);
@@ -31,7 +25,7 @@ function readSymbols() {
         });
       });
 
-  console.log("Processing datetime symbols ...");
+  console.log('Processing datetime symbols ...');
   var datetimeStagePromise = qfs.read(__dirname + '/../closure/datetimeSymbols.js', 'b')
       .then(function(content) {
         closureI18nExtractor.extractDateTimeSymbols(content, localeInfo);
@@ -77,7 +71,7 @@ function writeLocaleFiles() {
     var content = closureI18nExtractor.outputLocale(localeInfo, localeID);
     if (!content) return;
     var correctedLocaleId = closureI18nExtractor.correctedLocaleId(localeID);
-    var filename = NG_LOCALE_DIR + 'angular-locale_' + correctedLocaleId + '.js'
+    var filename = NG_LOCALE_DIR + 'angular-locale_' + correctedLocaleId + '.js';
     console.log('Writing ' + filename);
     return qfs.write(filename, content)
         .then(function() {
@@ -95,7 +89,8 @@ function writeLocaleFiles() {
 function createFolder(folder) {
   return qfs.isDirectory(folder).then(function(isDir) {
     if (!isDir) return qfs.makeDirectory(folder).then(function() {
-        console.log('Created directory %j', folder); });
+      console.log('Created directory %j', folder);
+    });
   });
 }
 
@@ -103,4 +98,4 @@ createFolder(NG_LOCALE_DIR)
   .then(readSymbols)
   .then(extractPlurals)
   .then(writeLocaleFiles)
-  .done(function(num_files) { console.log("Wrote %j files.\nAll Done!", num_files); });
+  .done(function(num_files) { console.log('Wrote %j files.\nAll Done!', num_files); });
