@@ -1,3 +1,5 @@
+'use strict';
+
 var angularFiles = require('./angularFiles');
 var sharedConfig = require('./karma-shared.conf');
 
@@ -5,12 +7,7 @@ module.exports = function(config) {
   sharedConfig(config, {testName: 'AngularJS: jqLite', logFile: 'karma-jqlite.log'});
 
   config.set({
-    files: angularFiles.mergeFilesFor('karma').concat({
-      pattern: "test/fixtures/**/*.html",
-      served: true,
-      watched: true,
-      included: false
-    }),
+    files: angularFiles.mergeFilesFor('karma'),
     exclude: angularFiles.mergeFilesFor('karmaExclude'),
 
     junitReporter: {
