@@ -7,7 +7,7 @@ module.exports = function(config) {
   sharedConfig(config, {testName: 'AngularJS: modules', logFile: 'karma-modules.log'});
 
   config.set({
-    files: angularFiles.mergeFilesFor('karmaModules', 'angularSrcModules'),
+    files: angularFiles.mergeFilesFor('karmaModules'),
 
     junitReporter: {
       outputFile: 'test_out/modules.xml',
