@@ -4,7 +4,7 @@
 
 var bower = require('bower');
 var util = require('./utils.js');
-var shelljs = require('shelljs');
+var npmRun = require('npm-run');
 
 module.exports = function(grunt) {
 
@@ -39,10 +39,7 @@ module.exports = function(grunt) {
 
 
   grunt.registerTask('docs', 'create angular docs', function() {
-    var gruntProc = shelljs.exec('npm run gulp -- --gulpfile docs/gulpfile.js');
-    if (gruntProc.code !== 0) {
-      throw new Error('doc generation failed');
-    }
+    npmRun.execSync('gulp --gulpfile docs/gulpfile.js', {stdio: 'inherit'});
   });
 
 
