@@ -35,7 +35,7 @@ var getPackage = function() {
  * @return {Object} An object containing the github owner and repository name
  */
 var getGitRepoInfo = function() {
-  var GITURL_REGEX = /^https:\/\/github.com\/([^\/]+)\/(.+).git$/;
+  var GITURL_REGEX = /^https:\/\/github.com\/([^/]+)\/(.+).git$/;
   var match = GITURL_REGEX.exec(currentPackage.repository.url);
   var git = {
     owner: match[1],
