@@ -124,7 +124,7 @@ describe('injector', function() {
     expect($injector).not.toBe(providerInjector);
   }));
 
-  it('should have an false strictDi property', inject(function($injector) {
+  it('should have a false strictDi property', inject(function($injector) {
     expect($injector.strictDi).toBe(false);
   }));
 
@@ -192,7 +192,7 @@ describe('injector', function() {
 
 
     it('should create $inject', function() {
-      var extraParans = angular.noop;
+      var extraParams = angular.noop;
       /* eslint-disable space-before-function-paren */
       // keep the multi-line to make sure we can handle it
       function $f_n0 /*
@@ -203,7 +203,7 @@ describe('injector', function() {
                  function(a, b) {}
                  */
           _c,
-          /* {some type} */ d) { extraParans(); }
+          /* {some type} */ d) { extraParams(); }
       /* eslint-enable */
       expect(annotate($f_n0)).toEqual(['$a', 'b_', '_c',  'd']);
       expect($f_n0.$inject).toEqual(['$a', 'b_', '_c',  'd']);
@@ -418,7 +418,7 @@ describe('injector', function() {
       expect(function() {
         createInjector(['IDontExist'], {});
       }).toThrowMinErr('$injector', 'modulerr',
-        /\[\$injector:nomod\] Module 'IDontExist' is not available! You either misspelled the module name or forgot to load it/);
+        /\[\$injector:nomod] Module 'IDontExist' is not available! You either misspelled the module name or forgot to load it/);
     });
 
 
@@ -782,7 +782,7 @@ describe('injector', function() {
           createInjector([
             {}
           ], {});
-        }).toThrowMinErr('$injector', 'modulerr', /Failed to instantiate module \{\} due to:\n.*\[ng:areq\] Argument 'module' is not a function, got Object/);
+        }).toThrowMinErr('$injector', 'modulerr', /Failed to instantiate module \{\} due to:\n.*\[ng:areq] Argument 'module' is not a function, got Object/);
       });
 
 
@@ -944,7 +944,7 @@ describe('injector', function() {
     });
 
 
-    it('should throw usefull error on wrong argument type]', function() {
+    it('should throw useful error on wrong argument type]', function() {
       expect(function() {
         $injector.invoke({});
       }).toThrowMinErr('ng', 'areq', 'Argument \'fn\' is not a function, got Object');
@@ -1062,7 +1062,7 @@ describe('injector', function() {
         createInjector([function($provide) {
           $provide.value('name', 'angular');
         }, instanceLookupInModule]);
-      }).toThrowError(/\[\$injector:unpr] Unknown provider: name/);
+      }).toThrowMinErr('$injector', 'modulerr', '[$injector:unpr] Unknown provider: name');
     });
   });
 });
