@@ -23,17 +23,13 @@ if (window.jQuery) {
       expect(divSpy).not.toHaveBeenCalled();
 
       expect(spy1).toHaveBeenCalled();
-      expect(spy1.callCount).toEqual(1);
+      expect(spy1).toHaveBeenCalledTimes(1);
       expect(spy2).toHaveBeenCalled();
-      expect(spy2.callCount).toEqual(1);
+      expect(spy2).toHaveBeenCalledTimes(1);
     });
 
     describe('$detach event', function() {
 
-      it('should fire on detach()', function() {
-        doc.find('span').detach();
-      });
-
       it('should fire on remove()', function() {
         doc.find('span').remove();
       });
@@ -72,8 +68,8 @@ if (window.jQuery) {
       spy1 = jasmine.createSpy('span1.$destroy');
       spy2 = jasmine.createSpy('span2.$destroy');
       doc = $('<div><span class=first>abc</span><span class=second>xyz</span></div>');
-      doc.find('span.first').bind('$destroy', spy1);
-      doc.find('span.second').bind('$destroy', spy2);
+      doc.find('span.first').on('$destroy', spy1);
+      doc.find('span.second').on('$destroy', spy2);
     });
 
     afterEach(function() {
@@ -83,16 +79,10 @@ if (window.jQuery) {
 
     describe('$detach event is not invoked in too many cases', function() {
 
-      it('should fire only on matched elements on detach(selector)', function() {
-        doc.find('span').detach('.second');
-        expect(spy2).toHaveBeenCalled();
-        expect(spy2.callCount).toEqual(1);
-      });
-
       it('should fire only on matched elements on remove(selector)', function() {
         doc.find('span').remove('.second');
         expect(spy2).toHaveBeenCalled();
-        expect(spy2.callCount).toEqual(1);
+        expect(spy2).toHaveBeenCalledTimes(1);
       });
 
       it('should not fire on html()', function() {
