@@ -34,7 +34,7 @@ describe('minErr', function() {
 
   it('should interpolate string arguments without quotes', function() {
     var myError = testError('1', 'This {0} is "{1}"', 'foo', 'bar');
-    expect(myError.message).toMatch(/^\[test:1\] This foo is "bar"/);
+    expect(myError.message).toMatch(/^\[test:1] This foo is "bar"/);
   });
 
   it('should interpolate non-string arguments', function() {
@@ -57,7 +57,7 @@ describe('minErr', function() {
     var myError = testError('26', 'false: {0}; zero: {1}; null: {2}; undefined: {3}; emptyStr: {4}',
                                    false,      0,         null,      undefined,      '');
     expect(myError.message).
-        toMatch(/^\[test:26\] false: false; zero: 0; null: null; undefined: undefined; emptyStr: /);
+        toMatch(/^\[test:26] false: false; zero: 0; null: null; undefined: undefined; emptyStr: /);
   });
 
   it('should handle arguments that are objects with cyclic references', function() {
@@ -74,20 +74,20 @@ describe('minErr', function() {
     var foo = 'Fooooo',
         myError = testError('26', 'This {0} is {1} on {2}', foo);
 
-    expect(myError.message).toMatch(/^\[test:26\] This Fooooo is \{1\} on \{2\}/);
+    expect(myError.message).toMatch(/^\[test:26] This Fooooo is \{1\} on \{2\}/);
   });
 
 
   it('should pass through the message if no interpolation is needed', function() {
     var myError = testError('26', 'Something horrible happened!');
-    expect(myError.message).toMatch(/^\[test:26\] Something horrible happened!/);
+    expect(myError.message).toMatch(/^\[test:26] Something horrible happened!/);
   });
 
   it('should include a namespace in the message only if it is namespaced', function() {
     var myError = emptyTestError('26', 'This is a {0}', 'Foo');
     var myNamespacedError = testError('26', 'That is a {0}', 'Bar');
-    expect(myError.message).toMatch(/^\[26\] This is a Foo/);
-    expect(myNamespacedError.message).toMatch(/^\[test:26\] That is a Bar/);
+    expect(myError.message).toMatch(/^\[26] This is a Foo/);
+    expect(myNamespacedError.message).toMatch(/^\[test:26] That is a Bar/);
   });
 
 
