@@ -12,10 +12,14 @@ describe('event directives', function() {
   describe('ngSubmit', function() {
 
     it('should get called on form submit', inject(function($rootScope, $compile) {
-      element = $compile('<form action="" ng-submit="submitted = true">' +
+      element = $compile('<form action="/foo" ng-submit="submitted = true">' +
         '<input type="submit"/>' +
         '</form>')($rootScope);
       $rootScope.$digest();
+
+      // prevent submit within the test harness
+      element.on('submit', function(e) { e.preventDefault(); });
+
       expect($rootScope.submitted).not.toBeDefined();
 
       browserTrigger(element.children()[0]);
@@ -29,10 +33,14 @@ describe('event directives', function() {
         }
       };
 
-      element = $compile('<form action="" ng-submit="formSubmission($event)">' +
+      element = $compile('<form action="/foo" ng-submit="formSubmission($event)">' +
         '<input type="submit"/>' +
         '</form>')($rootScope);
       $rootScope.$digest();
+
+      // prevent submit within the test harness
+      element.on('submit', function(e) { e.preventDefault(); });
+
       expect($rootScope.formSubmitted).not.toBeDefined();
 
       browserTrigger(element.children()[0]);
@@ -70,7 +78,7 @@ describe('event directives', function() {
     it('should call the listener synchronously inside of $apply if outside of $apply',
         inject(function($rootScope, $compile) {
       element = $compile('<input type="text" ng-focus="focus()" ng-model="value">')($rootScope);
-      $rootScope.focus = jasmine.createSpy('focus').andCallFake(function() {
+      $rootScope.focus = jasmine.createSpy('focus').and.callFake(function() {
         $rootScope.value = 'newValue';
       });
 
@@ -131,7 +139,7 @@ describe('event directives', function() {
     it('should call the listener synchronously inside of $apply if outside of $apply',
         inject(function($rootScope, $compile) {
       element = $compile('<input type="text" ng-blur="blur()" ng-model="value">')($rootScope);
-      $rootScope.blur = jasmine.createSpy('blur').andCallFake(function() {
+      $rootScope.blur = jasmine.createSpy('blur').and.callFake(function() {
         $rootScope.value = 'newValue';
       });
 
