@@ -827,21 +827,15 @@ describe('ngModel', function() {
 
 
       it('should only validate to true if all validations are true', function() {
-        var curry = function(v) {
-          return function() {
-            return v;
-          };
-        };
-
         ctrl.$modelValue = undefined;
-        ctrl.$validators.a = curry(true);
-        ctrl.$validators.b = curry(true);
-        ctrl.$validators.c = curry(false);
+        ctrl.$validators.a = valueFn(true);
+        ctrl.$validators.b = valueFn(true);
+        ctrl.$validators.c = valueFn(false);
 
         ctrl.$validate();
         expect(ctrl.$valid).toBe(false);
 
-        ctrl.$validators.c = curry(true);
+        ctrl.$validators.c = valueFn(true);
 
         ctrl.$validate();
         expect(ctrl.$valid).toBe(true);
@@ -849,16 +843,10 @@ describe('ngModel', function() {
 
 
       it('should register invalid validations on the $error object', function() {
-        var curry = function(v) {
-          return function() {
-            return v;
-          };
-        };
-
         ctrl.$modelValue = undefined;
-        ctrl.$validators.unique = curry(false);
-        ctrl.$validators.tooLong = curry(false);
-        ctrl.$validators.notNumeric = curry(true);
+        ctrl.$validators.unique = valueFn(false);
+        ctrl.$validators.tooLong = valueFn(false);
+        ctrl.$validators.notNumeric = valueFn(true);
 
         ctrl.$validate();
 
@@ -1327,7 +1315,7 @@ describe('ngModel', function() {
 
 
   describe('CSS classes', function() {
-    var EMAIL_REGEXP = /^[a-z0-9!#$%&'*+\/=?^_`{|}~.-]+@[a-z0-9]([a-z0-9-]*[a-z0-9])?(\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$/i;
+    var EMAIL_REGEXP = /^[a-z0-9!#$%&'*+/=?^_`{|}~.-]+@[a-z0-9]([a-z0-9-]*[a-z0-9])?(\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$/i;
 
     it('should set ng-empty or ng-not-empty when the view value changes',
           inject(function($compile, $rootScope, $sniffer) {
