@@ -516,15 +516,12 @@ describe('ngRepeat', function() {
           '  <div ng-repeat="' + expression + '">{{item}}</div>' +
           '</div>')(scope);
 
-        var expected = new RegExp('^\\[ngRepeat:badident\\] alias \'' + escape(expr) + '\' is invalid --- must be a valid JS identifier which is not a reserved name');
-        expect($exceptionHandler.errors.shift()[0].message).
-          toMatch(expected);
+        expect($exceptionHandler.errors.shift()[0]).toEqualMinErr('ngRepeat', 'badident',
+            'alias \'' + expr + '\' is invalid --- must be a valid JS identifier which is not a ' +
+            'reserved name');
+
         dealoc(element);
       });
-
-      function escape(text) {
-        return text.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&');
-      }
     }));
   });
 
@@ -580,16 +577,18 @@ describe('ngRepeat', function() {
   it('should error on wrong parsing of ngRepeat', function() {
     element = jqLite('<ul><li ng-repeat="i dont parse"></li></ul>');
     $compile(element)(scope);
-    expect($exceptionHandler.errors.shift()[0].message).
-        toMatch(/^\[ngRepeat:iexp\] Expected expression in form of '_item_ in _collection_\[ track by _id_\]' but got 'i dont parse'\./);
+    expect($exceptionHandler.errors.shift()[0]).toEqualMinErr('ngRepeat', 'iexp',
+        'Expected expression in form of \'_item_ in _collection_[ track by _id_]\' but got ' +
+        '\'i dont parse\'.');
   });
 
 
   it('should throw error when left-hand-side of ngRepeat can\'t be parsed', function() {
     element = jqLite('<ul><li ng-repeat="i dont parse in foo"></li></ul>');
     $compile(element)(scope);
-    expect($exceptionHandler.errors.shift()[0].message).
-      toMatch(/^\[ngRepeat:iidexp\] '_item_' in '_item_ in _collection_' should be an identifier or '\(_key_, _value_\)' expression, but got 'i dont parse'\./);
+    expect($exceptionHandler.errors.shift()[0]).toEqualMinErr('ngRepeat', 'iidexp',
+        '\'_item_\' in \'_item_ in _collection_\' should be an identifier or ' +
+        '\'(_key_, _value_)\' expression, but got \'i dont parse\'.');
   });
 
 
@@ -1141,9 +1140,10 @@ describe('ngRepeat', function() {
     it('should throw error on adding existing duplicates and recover', function() {
       scope.items = [a, a, a];
       scope.$digest();
-      expect($exceptionHandler.errors.shift().message).
-          toMatch(
-            /^\[ngRepeat:dupes] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:3, Duplicate value: {}/);
+      expect($exceptionHandler.errors.shift()).toEqualMinErr('ngRepeat', 'dupes',
+          'Duplicates in a repeater are not allowed. ' +
+          'Use \'track by\' expression to specify unique keys. ' +
+          'Repeater: item in items, Duplicate key: object:3, Duplicate value: {}');
 
       // recover
       scope.items = [a];
@@ -1162,9 +1162,10 @@ describe('ngRepeat', function() {
     it('should throw error on new duplicates and recover', function() {
       scope.items = [d, d, d];
       scope.$digest();
-      expect($exceptionHandler.errors.shift().message).
-          toMatch(
-            /^\[ngRepeat:dupes] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:9, Duplicate value: {}/);
+      expect($exceptionHandler.errors.shift()).toEqualMinErr('ngRepeat', 'dupes',
+          'Duplicates in a repeater are not allowed. ' +
+          'Use \'track by\' expression to specify unique keys. ' +
+          'Repeater: item in items, Duplicate key: object:9, Duplicate value: {}');
 
       // recover
       scope.items = [a];
