@@ -3,8 +3,8 @@
 describe('$document', function() {
 
 
-  it("should inject $document", inject(function($document) {
-    expect($document).toEqual(jqLite(document));
+  it('should inject $document', inject(function($document) {
+    expect($document).toEqual(jqLite(window.document));
   }));
 
 
