@@ -14,7 +14,7 @@ describe('$$animation', function() {
     $$animationProvider.drivers.length = 0;
   }));
 
-  it("should not run an animation if there are no drivers",
+  it('should not run an animation if there are no drivers',
     inject(function($$animation, $animate, $rootScope) {
 
     element = jqLite('<div></div>');
@@ -27,7 +27,7 @@ describe('$$animation', function() {
     expect(done).toBe(true);
   }));
 
-  it("should not run an animation if no drivers return an animation step function", function() {
+  it('should not run an animation if no drivers return an animation step function', function() {
     module(function($$animationProvider, $provide) {
       $$animationProvider.drivers.push('matiasDriver');
       $provide.value('matiasDriver', function() {
@@ -47,8 +47,8 @@ describe('$$animation', function() {
     });
   });
 
-  describe("drivers", function() {
-    it("should use the first driver that returns a step function", function() {
+  describe('drivers', function() {
+    it('should use the first driver that returns a step function', function() {
       var count = 0;
       var activeDriver;
       module(function($$animationProvider, $provide) {
@@ -111,7 +111,7 @@ describe('$$animation', function() {
         });
       }));
 
-      it("should obtain the element, event, the provided options and the domOperation",
+      it('should obtain the element, event, the provided options and the domOperation',
         inject(function($$animation, $rootScope, $rootElement) {
         $rootElement.append(element);
 
@@ -135,7 +135,7 @@ describe('$$animation', function() {
         expect(domOperationCalled).toBe(true);
       }));
 
-      it("should obtain the classes string which is a combination of className, addClass and removeClass",
+      it('should obtain the classes string which is a combination of className, addClass and removeClass',
         inject(function($$animation, $rootScope, $rootElement) {
 
         element.addClass('blue red');
@@ -154,7 +154,7 @@ describe('$$animation', function() {
       }));
     });
 
-    it("should traverse the drivers in reverse order", function() {
+    it('should traverse the drivers in reverse order', function() {
       var log = [];
       module(function($$animationProvider, $provide) {
         $$animationProvider.drivers.push('first');
@@ -180,7 +180,7 @@ describe('$$animation', function() {
       });
     });
 
-    they("should $prop the animation call if the driver $proped the returned promise",
+    they('should $prop the animation call if the driver $proped the returned promise',
       ['resolve', 'reject'], function(event) {
 
       module(function($$animationProvider, $provide) {
@@ -208,7 +208,11 @@ describe('$$animation', function() {
         // the animation is started
         $rootScope.$digest();
 
-        event === 'resolve' ? runner.end() : runner.cancel();
+        if (event === 'resolve') {
+          runner.end();
+        } else {
+          runner.cancel();
+        }
 
         // the resolve/rejection digest
         $animate.flush();
@@ -218,7 +222,7 @@ describe('$$animation', function() {
       });
     });
 
-    they("should $prop the driver animation when runner.$prop() is called",
+    they('should $prop the driver animation when runner.$prop() is called',
       ['cancel', 'end'], function(method) {
 
       var log = [];
@@ -289,7 +293,7 @@ describe('$$animation', function() {
       }
     }));
 
-    describe("singular", function() {
+    describe('singular', function() {
       beforeEach(module(function($provide) {
         element = jqLite('<div></div>');
         return function($rootElement) {
@@ -534,7 +538,7 @@ describe('$$animation', function() {
       });
     });
 
-    describe("grouped", function() {
+    describe('grouped', function() {
       var fromElement;
       var toElement;
       var fromAnchors;
@@ -565,7 +569,7 @@ describe('$$animation', function() {
         };
       }));
 
-      it("should group animations together when they have shared anchors and a shared CSS class",
+      it('should group animations together when they have shared anchors and a shared CSS class',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('shared-class');
@@ -596,7 +600,7 @@ describe('$$animation', function() {
         assertCompareNodes(toElm, anchors['in']);
       }));
 
-      it("should group animations together and properly match up multiple anchors based on their references",
+      it('should group animations together and properly match up multiple anchors based on their references',
         inject(function($$animation, $rootScope) {
 
         var attr = 'ng-animate-ref';
@@ -628,7 +632,7 @@ describe('$$animation', function() {
         assertCompareNodes(toAnchors[1], anchors[2]['in']);
       }));
 
-      it("should group animations together on the from and to elements if their both contain matching anchors",
+      it('should group animations together on the from and to elements if their both contain matching anchors',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('shared-class');
@@ -646,7 +650,7 @@ describe('$$animation', function() {
         assertCompareNodes(toElement, anchors['in']);
       }));
 
-      it("should not group animations into an anchored animation if enter/leave events are NOT used",
+      it('should not group animations into an anchored animation if enter/leave events are NOT used',
         inject(function($$animation, $rootScope, $$rAF) {
 
         fromElement.addClass('shared-class');
@@ -666,7 +670,7 @@ describe('$$animation', function() {
         expect(captureLog.length).toBe(2);
       }));
 
-      it("should not group animations together if a matching pair of anchors is not detected",
+      it('should not group animations together if a matching pair of anchors is not detected',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('shared-class');
@@ -682,7 +686,7 @@ describe('$$animation', function() {
         expect(captureLog.length).toBe(2);
       }));
 
-      it("should not group animations together if a matching CSS class is not detected",
+      it('should not group animations together if a matching CSS class is not detected',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('even-class');
@@ -698,7 +702,7 @@ describe('$$animation', function() {
         expect(captureLog.length).toBe(2);
       }));
 
-      it("should expose the shared CSS class in the options provided to the driver",
+      it('should expose the shared CSS class in the options provided to the driver',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('fresh-class');
@@ -714,7 +718,7 @@ describe('$$animation', function() {
         expect(capturedAnimation.classes).toBe('fresh-class');
       }));
 
-      it("should update the runner methods to the grouped runner methods handled by the driver",
+      it('should update the runner methods to the grouped runner methods handled by the driver',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('group-1');
@@ -734,7 +738,7 @@ describe('$$animation', function() {
         expect(runner1.cancel).toBe(runner2.cancel);
       }));
 
-      they("should end the animation if the $prop element is prematurely removed from the DOM during the animation", ['from', 'to'], function(event) {
+      they('should end the animation if the $prop element is prematurely removed from the DOM during the animation', ['from', 'to'], function(event) {
         inject(function($$animation, $rootScope) {
           fromElement.addClass('group-1');
           $$animation(fromElement, 'leave');
@@ -748,12 +752,12 @@ describe('$$animation', function() {
 
           expect(runnerLog).toEqual([]);
 
-          ('from' ? fromElement : toElement).remove();
+          (event === 'from' ? fromElement : toElement).remove();
           expect(runnerLog).toEqual(['end']);
         });
       });
 
-      it("should not end the animation when the `from` animation calls its own leave dom operation",
+      it('should not end the animation when the `from` animation calls its own leave dom operation',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('group-1');
@@ -783,7 +787,7 @@ describe('$$animation', function() {
         expect(runnerLog).toEqual([]);
       }));
 
-      it("should not end the animation if any of the anchor elements are removed from the DOM during the animation",
+      it('should not end the animation if any of the anchor elements are removed from the DOM during the animation',
         inject(function($$animation, $rootScope) {
 
         fromElement.addClass('group-1');
@@ -862,7 +866,8 @@ describe('$$animation', function() {
         mockedDriverFn = function(element, method, options, domOperation) {
           return {
             start: function() {
-              return runner = new $$AnimateRunner();
+              runner = new $$AnimateRunner();
+              return runner;
             }
           };
         };
