@@ -26,18 +26,18 @@ describe('ngMock', function() {
 
 
     it('should fake getLocalDateString method', function() {
-      var millenium = new Date('2000').getTime();
+      var millennium = new Date('2000').getTime();
 
-      // millenium in -3h
-      var t0 = new angular.mock.TzDate(-3, millenium);
+      // millennium in -3h
+      var t0 = new angular.mock.TzDate(-3, millennium);
       expect(t0.toLocaleDateString()).toMatch('2000');
 
-      // millenium in +0h
-      var t1 = new angular.mock.TzDate(0, millenium);
+      // millennium in +0h
+      var t1 = new angular.mock.TzDate(0, millennium);
       expect(t1.toLocaleDateString()).toMatch('2000');
 
-      // millenium in +3h
-      var t2 = new angular.mock.TzDate(3, millenium);
+      // millennium in +3h
+      var t2 = new angular.mock.TzDate(3, millennium);
       expect(t2.toLocaleDateString()).toMatch('1999');
     });
 
@@ -1674,7 +1674,7 @@ describe('ngMock', function() {
             expect(callback).toHaveBeenCalledOnceWith(200, 'path', '', '');
           }
         );
-        they('should match colon deliminated parameters in ' + routeShortcut + ' $prop method', methods,
+        they('should match colon delimited parameters in ' + routeShortcut + ' $prop method', methods,
           function() {
             hb[routeShortcut](this, '/route/:id/path/:s_id').respond('path');
             hb(this, '/route/123/path/456', undefined, callback);
@@ -1947,27 +1947,15 @@ describe('ngMock', function() {
 
 
   describe('$controllerDecorator', function() {
-    it('should support creating controller with bindings', function() {
-      var called = false;
-      var data = [
-        { name: 'derp1', id: 0 },
-        { name: 'testname', id: 1 },
-        { name: 'flurp', id: 2 }
-      ];
-      module(function($controllerProvider) {
-        $controllerProvider.register('testCtrl', function() {
-          called = true;
-          expect(this.data).toBe(data);
-        });
-      });
-      inject(function($controller, $rootScope) {
-        $controller('testCtrl', { scope: $rootScope }, { data: data });
-        expect(called).toBe(true);
-      });
-    });
 
-    it('should support assigning bindings when a value is returned from the constructor',
-      function() {
+    describe('with `preAssignBindingsEnabled(true)`', function() {
+
+      beforeEach(module(function($compileProvider) {
+        $compileProvider.preAssignBindingsEnabled(true);
+      }));
+
+
+      it('should support creating controller with bindings', function() {
         var called = false;
         var data = [
           { name: 'derp1', id: 0 },
@@ -1976,10 +1964,8 @@ describe('ngMock', function() {
         ];
         module(function($controllerProvider) {
           $controllerProvider.register('testCtrl', function() {
-            called = true;
             expect(this.data).toBe(data);
-
-            return {};
+            called = true;
           });
         });
         inject(function($controller, $rootScope) {
@@ -1987,11 +1973,64 @@ describe('ngMock', function() {
           expect(ctrl.data).toBe(data);
           expect(called).toBe(true);
         });
-      }
-    );
+      });
 
-    if (/chrome/.test(window.navigator.userAgent)) {
-      it('should support assigning bindings to class-based controller', function() {
+
+      it('should support assigning bindings when a value is returned from the constructor',
+        function() {
+          var called = false;
+          var data = [
+            { name: 'derp1', id: 0 },
+            { name: 'testname', id: 1 },
+            { name: 'flurp', id: 2 }
+          ];
+          module(function($controllerProvider) {
+            $controllerProvider.register('testCtrl', function() {
+              expect(this.data).toBe(data);
+              called = true;
+              return {};
+            });
+          });
+          inject(function($controller, $rootScope) {
+            var ctrl = $controller('testCtrl', { scope: $rootScope }, { data: data });
+            expect(ctrl.data).toBe(data);
+            expect(called).toBe(true);
+          });
+        }
+      );
+
+
+      if (/chrome/.test(window.navigator.userAgent)) {
+        it('should support assigning bindings to class-based controller', function() {
+          var called = false;
+          var data = [
+            { name: 'derp1', id: 0 },
+            { name: 'testname', id: 1 },
+            { name: 'flurp', id: 2 }
+          ];
+          module(function($controllerProvider) {
+            // eslint-disable-next-line no-eval
+            var TestCtrl = eval('(class { constructor() { called = true; } })');
+            $controllerProvider.register('testCtrl', TestCtrl);
+          });
+          inject(function($controller, $rootScope) {
+            var ctrl = $controller('testCtrl', { scope: $rootScope }, { data: data });
+            expect(ctrl.data).toBe(data);
+            expect(called).toBe(true);
+          });
+        });
+      }
+    });
+
+
+    describe('with `preAssignBindingsEnabled(false)`', function() {
+
+      beforeEach(module(function($compileProvider) {
+        $compileProvider.preAssignBindingsEnabled(false);
+      }));
+
+
+      it('should support creating controller with bindings', function() {
         var called = false;
         var data = [
           { name: 'derp1', id: 0 },
@@ -1999,9 +2038,10 @@ describe('ngMock', function() {
           { name: 'flurp', id: 2 }
         ];
         module(function($controllerProvider) {
-          // eslint-disable-next-line no-eval
-          var TestCtrl = eval('(class { constructor() { called = true; } })');
-          $controllerProvider.register('testCtrl', TestCtrl);
+          $controllerProvider.register('testCtrl', function() {
+            expect(this.data).toBeUndefined();
+            called = true;
+          });
         });
         inject(function($controller, $rootScope) {
           var ctrl = $controller('testCtrl', { scope: $rootScope }, { data: data });
@@ -2009,7 +2049,53 @@ describe('ngMock', function() {
           expect(called).toBe(true);
         });
       });
-    }
+
+
+      it('should support assigning bindings when a value is returned from the constructor',
+        function() {
+          var called = false;
+          var data = [
+            { name: 'derp1', id: 0 },
+            { name: 'testname', id: 1 },
+            { name: 'flurp', id: 2 }
+          ];
+          module(function($controllerProvider) {
+            $controllerProvider.register('testCtrl', function() {
+              expect(this.data).toBeUndefined();
+              called = true;
+              return {};
+            });
+          });
+          inject(function($controller, $rootScope) {
+            var ctrl = $controller('testCtrl', { scope: $rootScope }, { data: data });
+            expect(ctrl.data).toBe(data);
+            expect(called).toBe(true);
+          });
+        }
+      );
+
+
+      if (/chrome/.test(window.navigator.userAgent)) {
+        it('should support assigning bindings to class-based controller', function() {
+          var called = false;
+          var data = [
+            { name: 'derp1', id: 0 },
+            { name: 'testname', id: 1 },
+            { name: 'flurp', id: 2 }
+          ];
+          module(function($controllerProvider) {
+            // eslint-disable-next-line no-eval
+            var TestCtrl = eval('(class { constructor() { called = true; } })');
+            $controllerProvider.register('testCtrl', TestCtrl);
+          });
+          inject(function($controller, $rootScope) {
+            var ctrl = $controller('testCtrl', { scope: $rootScope }, { data: data });
+            expect(ctrl.data).toBe(data);
+            expect(called).toBe(true);
+          });
+        });
+      }
+    });
   });
 
 
@@ -2748,7 +2834,7 @@ describe('sharedInjector', function() {
 
   // we use the 'module' and 'inject' globals from ngMock
 
-  it('allowes me to mutate a single instace of a module (proving it has been shared)', ngMockTest(function() {
+  it('allows me to mutate a single instance of a module (proving it has been shared)', ngMockTest(function() {
     sdescribe('test state is shared', function() {
       angular.module('sharedInjectorTestModuleA', [])
         .factory('testService', function() {
