@@ -615,10 +615,25 @@ describe('basic usage', function() {
 
   it('should bind default parameters', function() {
     $httpBackend.expect('GET', '/CreditCard/123.visa?minimum=0.05').respond({id: 123});
-    var Visa = CreditCard.bind({verb:'.visa', minimum:0.05});
-    var visa = Visa.get({id:123});
+    var Visa = CreditCard.bind({verb: '.visa', minimum: 0.05});
+    var visa = Visa.get({id: 123});
     $httpBackend.flush();
-    expect(visa).toEqualData({id:123});
+    expect(visa).toEqualData({id: 123});
+  });
+
+
+  it('should pass all original arguments when binding default params', function() {
+    $httpBackend.expect('GET', '/CancellableCreditCard/123.visa').respond({id: 123});
+
+    var CancellableCreditCard = $resource('/CancellableCreditCard/:id:verb', {},
+                                          {charge: {method: 'POST'}}, {cancellable: true});
+    var CancellableVisa = CancellableCreditCard.bind({verb: '.visa'});
+    var visa = CancellableVisa.get({id: 123});
+
+    $httpBackend.flush();
+
+    expect(visa.$charge).toEqual(jasmine.any(Function));
+    expect(visa.$cancelRequest).toEqual(jasmine.any(Function));
   });
 
 
@@ -1103,6 +1118,65 @@ describe('basic usage', function() {
   });
 
 
+  describe('success mode', function() {
+    it('should call the success callback (as 1st argument) on 2xx responses', function() {
+      var instance, headers, status, statusText;
+      var successCb = jasmine.createSpy('successCb').and.callFake(function(d, h, s, t) {
+        expect(d).toBe(instance);
+        expect(h()).toEqual(jasmine.objectContaining(headers));
+        expect(s).toBe(status);
+        expect(t).toBe(statusText);
+      });
+
+      instance = CreditCard.get(successCb);
+      headers = {foo: 'bar'};
+      status = 200;
+      statusText = 'OK';
+      $httpBackend.expect('GET', '/CreditCard').respond(status, {}, headers, statusText);
+      $httpBackend.flush();
+
+      expect(successCb).toHaveBeenCalledOnce();
+
+      instance = CreditCard.get(successCb);
+      headers = {baz: 'qux'};
+      status = 299;
+      statusText = 'KO';
+      $httpBackend.expect('GET', '/CreditCard').respond(status, {}, headers, statusText);
+      $httpBackend.flush();
+
+      expect(successCb).toHaveBeenCalledTimes(2);
+    });
+
+
+    it('should call the success callback (as 2nd argument) on 2xx responses', function() {
+      var instance, headers, status, statusText;
+      var successCb = jasmine.createSpy('successCb').and.callFake(function(d, h, s, t) {
+        expect(d).toBe(instance);
+        expect(h()).toEqual(jasmine.objectContaining(headers));
+        expect(s).toBe(status);
+        expect(t).toBe(statusText);
+      });
+
+      instance = CreditCard.get({id: 123}, successCb);
+      headers = {foo: 'bar'};
+      status = 200;
+      statusText = 'OK';
+      $httpBackend.expect('GET', '/CreditCard/123').respond(status, {}, headers, statusText);
+      $httpBackend.flush();
+
+      expect(successCb).toHaveBeenCalledOnce();
+
+      instance = CreditCard.get({id: 456}, successCb);
+      headers = {baz: 'qux'};
+      status = 299;
+      statusText = 'KO';
+      $httpBackend.expect('GET', '/CreditCard/456').respond(status, {}, headers, statusText);
+      $httpBackend.flush();
+
+      expect(successCb).toHaveBeenCalledTimes(2);
+    });
+  });
+
   describe('failure mode', function() {
     var ERROR_CODE = 500,
         ERROR_RESPONSE = 'Server Error',
@@ -1192,7 +1266,7 @@ describe('basic usage', function() {
         expect(user).toEqualData([{id: 1, name: 'user1'}]);
       });
 
-      it('should work with the action is overriden', function() {
+      it('should work with the action is overridden', function() {
         $httpBackend.expect('GET', '/users.json').respond([{id: 1, name: 'user1'}]);
         var UserService = $resource('/users/:user_id', {user_id: '@id'}, {
           query: {
@@ -1253,7 +1327,7 @@ describe('basic usage', function() {
         expect(user).toEqualData({id: 1, name: 'user1'});
       });
 
-      it('should work with the action is overriden', function() {
+      it('should work with the action is overridden', function() {
         $httpBackend.expect('GET', '/users/1.json').respond({id: 1, name: 'user1'});
         var UserService = $resource('/users/:user_id', {user_id: '@id'}, {
           get: {
@@ -1412,9 +1486,9 @@ describe('errors', function() {
 
     expect(successSpy).not.toHaveBeenCalled();
     expect(failureSpy).toHaveBeenCalled();
-    expect(failureSpy.calls.mostRecent().args[0]).toMatch(
-        /^\[\$resource:badcfg\] Error in resource configuration for action `query`\. Expected response to contain an array but got an object \(Request: GET \/Customer\/123\)/
-      );
+    expect(failureSpy.calls.mostRecent().args[0]).toEqualMinErr('$resource', 'badcfg',
+        'Error in resource configuration for action `query`. ' +
+        'Expected response to contain an array but got an object (Request: GET /Customer/123)');
   });
 
   it('should fail if action expects an array but response is an object', function() {
@@ -1429,9 +1503,9 @@ describe('errors', function() {
 
     expect(successSpy).not.toHaveBeenCalled();
     expect(failureSpy).toHaveBeenCalled();
-    expect(failureSpy.calls.mostRecent().args[0]).toMatch(
-        /^\[\$resource:badcfg\] Error in resource configuration for action `get`\. Expected response to contain an object but got an array \(Request: GET \/Customer\/123\)/
-      );
+    expect(failureSpy.calls.mostRecent().args[0]).toEqualMinErr('$resource', 'badcfg',
+        'Error in resource configuration for action `get`. ' +
+        'Expected response to contain an object but got an array (Request: GET /Customer/123)');
   });
 });
 
